import sys
sys.path.append('././')
from flask_restful import Api
from flask_migrate import Migrate
from flask import render_template
from db import create_app, db
from resources.account import Account, Accounts, PasswordChange, CompanyList, EmailTemplateList, CampaignList
from resources.email_template import EmailTemplate
from resources.login import Login
from resources.company import Company, EmployeesList
from resources.employee import Employee, EmployeeAddFallenCampaign
from resources.campaign import Campaign, ChangeStateCampaign
from resources.email_sender import SendPhishingEmail
from resources.statistics import Statistics, DataStatistics

app = create_app()
app.app_context().push()
api = Api(app)
# Migration imports, DO NOT REMOVE
from models.account import AccountModel
from models.company import CompanyModel
from models.employee import EmployeeModel
from models.email_template import EmailTemplateModel
from models.campaign import CampaignModel
from models.statistics import StatisticsModel

migrate = Migrate(app, db)

api.add_resource(Login, '/api/login')

api.add_resource(Account, '/api/account/<int:id>', '/api/account')
api.add_resource(Accounts, '/api/accounts/')
api.add_resource(PasswordChange, "/api/account/<int:idd>/change_password")
api.add_resource(CompanyList, '/api/account/<int:id>/company_list')
api.add_resource(EmailTemplateList, '/api/account/<int:id>/email_template_list')
api.add_resource(CampaignList, '/api/account/<int:id>/campaign_list')

api.add_resource(Company, '/api/company/<int:id>')
api.add_resource(EmployeesList, '/api/company/<int:id>/employees_list')

api.add_resource(Employee, '/api/employee/<int:id>')
api.add_resource(EmployeeAddFallenCampaign, '/api/addFallenCampaign/<int:id_employee>/<int:id_campaign>')

api.add_resource(EmailTemplate, '/api/email_template/<int:id>')

api.add_resource(Campaign, '/api/campaign/<int:id>')
api.add_resource(Statistics, '/api/statistics/<int:id>')
api.add_resource(DataStatistics, '/api/getData/<int:id>')
api.add_resource(ChangeStateCampaign, "/api/changeState/<int:id>")

api.add_resource(SendPhishingEmail, '/api/startCampaign/<int:id>')


@app.route('/')
def render_vue():
    return render_template("index.html"), 200


@app.errorhandler(404)
def return_index(e):
    return render_template("index.html"), 200


if __name__ == "__main__":
    app.run()
