from db import db

tags1 = db.Table('tags1', db.Column('campaigns_id', db.Integer, db.ForeignKey('campaign.id')),
                db.Column('companies_id', db.Integer, db.ForeignKey('company.id')))

tags2 = db.Table('tags2', db.Column('campaigns_id', db.Integer, db.ForeignKey('campaign.id')),
                db.Column('emailtemplate_id', db.Integer, db.ForeignKey('emailtemplate.id')))


class CampaignModel(db.Model):
    __tablename__ = 'campaign'

    id = db.Column(db.Integer, primary_key=True, unique=True)
    id_user = db.Column(db.Integer, db.ForeignKey('account.id'), nullable=False)
    name = db.Column(db.String(30), nullable=False)
    redirect_url = db.Column(db.String(), nullable=False)
    cheat_url = db.Column(db.String(), nullable=False)
    finish_date = db.Column(db.String(), nullable=False)
    state = db.Column(db.Integer, nullable=False)  # 0->Not started 1->Started 2->Finished
    get_data_url = db.Column(db.String(), nullable=False)

    companies = db.relationship('CompanyModel', secondary=tags1,
                                backref=db.backref('company_list_campaign', lazy='dynamic'))
    email_templates = db.relationship('EmailTemplateModel', secondary=tags2,
                                      backref=db.backref('email_template_list_campaign', lazy='dynamic'))

    statistics = db.relationship('StatisticsModel', backref='statistics_campaign', lazy=True)

    def __init__(self, id_user, name, redirect_url, cheat_url, finish_date, companies, email_templates, get_data_url):
        self.name = name
        self.id_user = id_user
        self.redirect_url = redirect_url
        self.cheat_url = cheat_url
        self.finish_date = finish_date
        self.companies = companies
        self.email_templates = email_templates
        self.get_data_url = get_data_url
        self.state = 0

    def save_to_db(self):
        db.session.add(self)
        db.session.commit()

    def delete_from_db(self):
        db.session.delete(self)
        db.session.commit()

    def json(self):
        return {"campaign": {
            'id': self.id,
            'name': self.name,
            'id_user': self.id_user,
            'redirect_url': self.redirect_url,
            'cheat_url': self.cheat_url,
            'finish_date': self.finish_date,
            'get_data_url': self.get_data_url,
            'companies': [a.json() for a in self.companies],
            'email_templates': [a.name for a in self.email_templates],
            'state': self.state,
            'statistics': [a.json() for a in self.statistics]
        }}

    @classmethod
    def find_by_id(cls, idd):
        return db.session.query(CampaignModel).filter_by(id=idd).first()
