from db import db


class CompanyModel(db.Model):
    __tablename__ = 'company'

    id = db.Column(db.Integer, primary_key=True, unique=True)
    id_user = db.Column(db.Integer, db.ForeignKey('account.id'), nullable=False)
    name = db.Column(db.String(30), nullable=False)

    employees = db.relationship('EmployeeModel', backref='employee_list_company', lazy=True)

    def __init__(self, id_user, name):
        self.id_user = id_user
        self.name = name

    def save_to_db(self):
        db.session.add(self)
        db.session.commit()

    def delete_from_db(self):
        db.session.delete(self)
        db.session.commit()

    def json(self):
        return {"Company": {
            'id': self.id,
            'id_user': self.id_user,
            'name': self.name,
            'employees': [a.json() for a in self.employees]
        }}

    @classmethod
    def find_by_id(cls, idd):
        return db.session.query(CompanyModel).filter_by(id=idd).first()

    @classmethod
    def find_by_name(cls, name):
        return db.session.query(CompanyModel).filter_by(name=name).first()
