from db import db

tags3 = db.Table('tags3', db.Column('employee_id', db.Integer, db.ForeignKey('employee.id')),
                db.Column('campaign_id', db.Integer, db.ForeignKey('campaign.id')))


class EmployeeModel(db.Model):
    __tablename__ = 'employee'

    id = db.Column(db.Integer, primary_key=True, unique=True)
    id_company = db.Column(db.Integer, db.ForeignKey('company.id'), nullable=False)
    name = db.Column(db.String(30), nullable=False)
    lastname = db.Column(db.String(30), nullable=False)
    email = db.Column(db.String(30),  nullable=False)
    fallen_campaigns = db.relationship('CampaignModel', secondary=tags3, backref=db.backref('campaign__fallen_list',
                                                                                            lazy='dynamic'))

    def __init__(self, id_company, name, lastname, email):
        self.id_company = id_company
        self.name = name
        self.lastname = lastname
        self.email = email

    def save_to_db(self):
        db.session.add(self)
        db.session.commit()

    def delete_from_db(self):
        db.session.delete(self)
        db.session.commit()

    def json(self):
        return {"Employee": {
            'id': self.id,
            'id_company': self.id_company,
            'name': self.name,
            'lastname': self.lastname,
            'email': self.email,
            'fallen_campaigns': [a.name for a in self.fallen_campaigns]
        }}

    @classmethod
    def find_by_id(cls, idd):
        return db.session.query(EmployeeModel).filter_by(id=idd).first()

    @classmethod
    def find_by_email(cls, email):
        return db.session.query(EmployeeModel).filter_by(email=email).first()