from db import db
from models.campaign import CampaignModel


class StatisticsModel(db.Model):
    __tablename__ = 'statistics'

    id = db.Column(db.Integer, primary_key=True, unique=True)
    id_campaign = db.Column(db.Integer, db.ForeignKey('campaign.id'), nullable=False)
    num_companies = db.Column(db.Integer, nullable=False)
    num_total_employees = db.Column(db.Integer, nullable=False)

    def __init__(self, id_campaign, num_companies, num_total_employees):
        self.id_campaign = id_campaign
        self.num_companies = num_companies
        self.num_total_employees = num_total_employees

    def save_to_db(self):
        db.session.add(self)
        db.session.commit()

    def delete_from_db(self):
        db.session.delete(self)
        db.session.commit()

    def json(self):
        return {"statistics": {
            'id': self.id,
            'id_campaign': self.id_campaign,
            'num_companies': self.num_companies,
            'num_total_employees': self.num_total_employees
        }}

    @classmethod
    def find_by_id(cls, idd):
        return db.session.query(StatisticsModel).filter_by(id=idd).first()

    @classmethod
    def get_data(cls, total_employees, id):
        campaign = CampaignModel.find_by_id(id)
        companies, num_fallen = cls.get_name_companies(cls, campaign.companies, campaign.name, total_employees)
        return {'companies': companies,
                'num_fallen': num_fallen,
                'num_total_employees': total_employees}

    def get_name_companies(self, companies, name, te):
        data = []
        num_fallen = []
        fallen = -1
        for company in companies:
            data.append('Victimas ' + company.name)
            for employee in company.employees:
                fallen = 0
                for fallen_campaign in employee.fallen_campaigns:
                    if fallen_campaign.name == name:
                        fallen += 1
            num_fallen.append(fallen)

        t_fallen = 0
        for i in range(len(num_fallen)):
            t_fallen += num_fallen[i]

        asd = te-t_fallen
        num_fallen.insert(0, asd)

        return data, num_fallen
