from flask_restful import Resource, reqparse

from models.account import AccountModel, auth


class Account(Resource):

    def get(self, id):
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404
        return acc.json(), 200

    def post(self):
        parser = reqparse.RequestParser()

        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('lastname', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('email', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('password', type=str, required=True, help="This field cannot be left blank")

        data = parser.parse_args()
        if AccountModel.find_by_email(data['email']):
            return {"message": "Account already registered for that email address"}, 409
        acc = AccountModel(data['name'], data['lastname'], data['email'], data['password'])
        acc.save_to_db()
        return acc.json(), 200

    def put(self, id):
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('lastname', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('email', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()
        if AccountModel.find_by_email(data['email']):
            return {"message": "Account already registered for that email address"}, 409

        acc.name, acc.lastname, acc.email = data['name'], data['lastname'], data['email']

        acc.save_to_db()
        return acc.json(), 200

    def delete(self, id):
        account = AccountModel.find_by_id(id)
        if not account:
            return {'message': 'Account with id [{}] not found'.format(id)}, 404
        for i in account.companies:
            for a in i.employees:
                a.delete_from_db()
            i.delete_from_db()
        [a.delete_from_db() for a in account.email_templates]
        for i in account.campaigns:
            for a in i.statistics:
                a.delete_from_db()
            i.delete_from_db()
        account.delete_from_db()
        return {'message': 'Account with id[{}] deleted correctly'.format(id)}, 200


class Accounts(Resource):
    def get(self):
        accounts = []
        for a in AccountModel.query.all():
            accounts.append(a.json())
        return {"accounts": accounts}, 200


class PasswordChange(Resource):
    def put(self, idd):
        acc = AccountModel.find_by_id(idd)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(idd)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('old_password', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('new_password', type=str, required=True, help="This field cannot be left blank")

        data = parser.parse_args()

        if acc.verify_password(data['old_password']):
            acc.hash_password(data['new_password'])
            acc.save_to_db()
            return {"message": "Password changed correctly"}, 200
        return {'message': "Incorrect password"}, 406


class CompanyList(Resource):
    def get(self, id):
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404
        return {"companies": [a.json() for a in acc.companies]}, 200


class EmailTemplateList(Resource):
    def get(self, id):
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404
        return {"emailTemplate": [a.json() for a in acc.email_templates]}, 200


class CampaignList(Resource):
    def get(self, id):
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404
        return {"campaign": [a.json() for a in acc.campaigns]}, 200