from flask_restful import Resource, reqparse

from models.account import AccountModel
from models.campaign import CampaignModel
from models.company import CompanyModel
from models.email_template import EmailTemplateModel
from datetime import datetime

from models.statistics import StatisticsModel


class Campaign(Resource):

    def get(self, id):
        campaign = CampaignModel.find_by_id(id)
        if not campaign:
            return {"Message": "Campaign with ['id': {}] not found".format(id)}, 404
        return campaign.json(), 200

    def post(self, id):
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('redirect_url', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('cheat_url', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('finish_date', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('get_data_url', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('companies', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('email_templates', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()

        id_companies = data['companies'].split(",")
        companies = []
        for i in range(len(id_companies)):
            co = CompanyModel.find_by_id(id_companies[i])
            if co:
                companies.append(co)
            else:
                return {"Message": "company with ['id': {}] not found".format(id_companies[i])}, 404

        id_templates = data['email_templates'].split(",")
        email_templates = []
        for i in range(len(id_templates)):
            et = EmailTemplateModel.find_by_id(id_templates[i])
            if et:
                email_templates.append(et)
            else:
                return {"Message": "company with ['id': {}] not found".format(id_templates[i])}, 404

        campaign = CampaignModel(id, data['name'], data['redirect_url'], data['cheat_url'], data['finish_date'],
                                 companies, email_templates, data['get_data_url'])
        campaign.save_to_db()
        return campaign.json(), 200

    def put(self, id):
        campaign = CampaignModel.find_by_id(id)
        if not campaign:
            return {"Message": "Campaign with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('redirect_url', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('cheat_url', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('finish_date', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('get_data_url', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('companies', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('email_templates', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()

        id_companies = data['companies'].split(",")
        companies = []
        for i in range(len(id_companies)):
            co = CompanyModel.find_by_id(id_companies[i])
            if co:
                companies.append(co)
            else:
                return {"Message": "company with ['id': {}] not found".format(id_companies[i])}, 404

        id_templates = data['email_templates'].split(",")
        email_templates = []
        for i in range(len(id_templates)):
            et = EmailTemplateModel.find_by_id(id_templates[i])
            if et:
                email_templates.append(et)
            else:
                return {"Message": "company with ['id': {}] not found".format(id_templates[i])}, 404

        campaign.name = data['name']
        campaign.redirect_url = data['redirect_url']
        campaign.cheat_url = data['cheat_url']
        campaign.finish_date = data['finish_date']
        campaign.get_data_url = data['get_data_url']
        campaign.companies = companies
        campaign.email_templates = email_templates
        campaign.save_to_db()

        return campaign.json(), 200

    def delete(self, id):
        campaign = CampaignModel.find_by_id(id)
        if not campaign:
            return {'message': 'Campaign with id [{}] not found'.format(id)}, 404
        statistics = StatisticsModel.find_by_id(id)
        statistics.delete_from_db()
        campaign.delete_from_db()
        return {'message': 'Campaign with id[{}] deleted correctly'.format(id)}, 200


class ChangeStateCampaign(Resource):

    def put(self, id):
        campaign = CampaignModel.find_by_id(id)
        if not campaign:
            return {'message': 'Campaign with id [{}] not found'.format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('state', type=int, required=True, help="This field cannot be left blank")
        data = parser.parse_args()

        if data['state'] != campaign.state:
            d = datetime.strptime(campaign.finish_date, '%Y-%m-%d')
            if datetime.today() >= d:
                campaign.state = 2
                campaign.save_to_db()
                return campaign.json(), 200

            campaign.state = data['state']
            campaign.save_to_db()

        return campaign.json(), 200
