from flask_restful import Resource, reqparse

from models.account import AccountModel
from models.company import CompanyModel


class Company(Resource):

    def get(self, id):
        company = CompanyModel.find_by_id(id)
        if not company:
            return {"Message": "Company with ['id': {}] not found".format(id)}, 404
        return company.json(), 200

    def post(self, id):
        parser = reqparse.RequestParser()

        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")

        data = parser.parse_args()
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404
        co = CompanyModel.find_by_name(data['name'])
        if co:
            return {"message": "Company already registered for that name"}, 409
        company = CompanyModel(id, data['name'])
        company.save_to_db()
        return company.json(), 200

    def put(self, id):
        company = CompanyModel.find_by_id(id)
        if not company:
            return {"Message": "Company with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()
        if CompanyModel.find_by_name(data['name']):
            return {"message": "Company already registered for that name"}, 409

        company.name = data['name']
        company.save_to_db()
        return company.json(), 200

    def delete(self, id):
        company = CompanyModel.find_by_id(id)
        if not company:
            return {'message': 'Company with id [{}] not found'.format(id)}, 404
        for i in company.employees:
            i.delete_from_db()
        company.delete_from_db()
        return {'message': 'Company with id[{}] deleted correctly'.format(id)}, 200


class EmployeesList(Resource):

    def get(self, id):
        company = CompanyModel.find_by_id(id)
        if not company:
            return {"Message": "Company with ['id': {}] not found".format(id)}, 404
        return {'employees': [a.json() for a in company.employees]}, 200
