from flask_restful import Resource, reqparse

from models.email_template import EmailTemplateModel
from models.account import AccountModel


class EmailTemplate(Resource):

    def get(self, id):
        et = EmailTemplateModel.find_by_id(id)
        if not et:
            return {"Message": "Email template with ['id': {}] not found".format(id)}, 404
        return et.json(), 200

    def post(self, id):
        acc = AccountModel.find_by_id(id)
        if not acc:
            return {"Message": "Account with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('html_file', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('header', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()

        et = EmailTemplateModel(id, data['name'], data['html_file'], data['header'])
        et.save_to_db()
        et.html_file = data['html_file']
        et.save_to_db()
        return et.json(), 200

    def put(self, id):
        et = EmailTemplateModel.find_by_id(id)
        if not et:
            return {"Message": "Email template with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('html_file', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('header', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()

        et.name = data['name']
        et.html_file = data['html_file']
        et.header = data['header']
        et.save_to_db()
        return et.json(), 200

    def delete(self, id):
        et = EmailTemplateModel.find_by_id(id)
        if not et:
            return {"Message": "Email template with ['id': {}] not found".format(id)}, 404

        et.delete_from_db()
        return {'message': 'Email template with id[{}] deleted correctly'.format(id)}, 200