from flask_restful import Resource, reqparse

from models.campaign import CampaignModel
from models.employee import EmployeeModel
from models.company import CompanyModel


class Employee(Resource):

    def get(self, id):
        acc = EmployeeModel.find_by_id(id)
        if not acc:
            return {"Message": "Employee with ['id': {}] not found".format(id)}, 404
        return acc.json(), 200

    def post(self, id):
        company = CompanyModel.find_by_id(id)
        if not company:
            return {"Message": "Company with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('lastname', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('email', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()

        if EmployeeModel.find_by_email(data['email']):
            return {"message": "Employee already registered for that email address"}, 409
        employee = EmployeeModel(id, data['name'], data['lastname'], data['email'])
        employee.save_to_db()
        return employee.json(), 200

    def put(self, id):
        employee = EmployeeModel.find_by_id(id)
        if not employee:
            return {"Message": "Employee with ['id': {}] not found".format(id)}, 404

        parser = reqparse.RequestParser()
        parser.add_argument('name', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('lastname', type=str, required=True, help="This field cannot be left blank")
        parser.add_argument('email', type=str, required=True, help="This field cannot be left blank")
        data = parser.parse_args()

        if EmployeeModel.find_by_email(data['email']):
            return {"message": "Employee already registered for that email address"}, 409

        employee.name, employee.lastname, employee.email = data['name'], data['lastname'], data['email']

        employee.save_to_db()
        return employee.json(), 200

    def delete(self, id):
        employee = EmployeeModel.find_by_id(id)
        if not employee:
            return {'message': 'Employee with id [{}] not found'.format(id)}, 404
        employee.delete_from_db()
        return {'message': 'Employee with id[{}] deleted correctly'.format(id)}, 200


class EmployeeAddFallenCampaign(Resource):

    def post(self, id_employee, id_campaign):
        campaign = CampaignModel.find_by_id(id_campaign)
        if not campaign:
            return {"Message": "Campaign with ['id': {}] not found".format(id_campaign)}, 404

        employee = EmployeeModel.find_by_id(id_employee)
        if not employee:
            return {"Message": "employee with ['id': {}] not found".format(id_employee)}, 404

        if campaign not in employee.fallen_campaigns:
            employee.fallen_campaigns.append(campaign)
            employee.save_to_db()

        return 'Ok', 200